@@ -59,6 +59,12 @@ sub run {
     };
     $Config{d_alarm} and alarm $timeout;
 
+    if ($self->option('is_win32')) {
+        require Test::Smoke::Util::Win32ErrorMode;
+        $self->log_info("Changing ErrorMode settings to prevent popups");
+        Test::Smoke::Util::Win32ErrorMode::lower_error_settings();
+    }
+
    $self->run_smoke();
    chdir $cwd;
 }
